package geogebra.kernel.discrete.tsp.method;


import geogebra.kernel.discrete.tsp.gui.DemoPanel;

/**
 * ä¸€èˆ¬çš„ã�ªã‚°ãƒ©ãƒ•ã�®ãƒ‡ãƒ¢ã�®ã‚¤ãƒ³ã‚¿ãƒ¼ãƒ•ã‚§ãƒ¼ã‚¹
 * @author masayasu
 */
public interface GraphDemonstration {
	public void method(DemoPanel nodes);
}
